# New in 0.16.1 (2022-04-22)

## Changes

-   Update scArches Pancreas tutorial, DestVI tutorial ([#1520]).

## Breaking changes

-   {class}`~scvi.dataloaders.SemiSupervisedDataLoader` and {class}`~scvi.dataloaders.SemiSupervisedDataSplitter` no longer take `unlabeled_category` as an initial argument. Instead, the `unlabeled_category` is fetched from the labels state registry, assuming that the {class}`~scvi.data.AnnDataManager` object is registered with a {class}`~scvi.data.fields.LabelsWithUnlabeledObsField` ([#1515]).

## Bug Fixes

-   Bug fixed in {class}`~scvi.model.SCANVI` where `self._labeled_indices` was being improperly set ([#1515]).
-   Fix issue where {class}`~scvi.model.SCANVI.load_query_data` would not properly add an obs column with the unlabeled category when the `labels_key` was not present in the query data.
-   Disable extension of categories for labels in {class}`~scvi.model.SCANVI.load_query_data` ([#1519]).
-   Fix an issue with {meth}`~scvi.model.SCANVI.prepare_query_data` to ensure it does nothing when genes are completely matched ([#1520]).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1515]: https://github.com/YosefLab/scvi-tools/pull/1515
[#1519]: https://github.com/YosefLab/scvi-tools/pull/1519
[#1520]: https://github.com/YosefLab/scvi-tools/pull/1520
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
